#****************************************************************************
#
# Copyright (c) 2019 Micro Focus International, PLC. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:      Micro Focus.
#  Workfile:    ncs-completion.sh
#  Contents:    Command line implementation for Novell Cluster Services
#                               and Novell Business Continuity Cluster.
#
#****************************************************************************
resourceList2()
{
	count=($(cluster resources | cut -f 1 -d ' ' | wc -l))
	count=$((count-1))
	echo $(cluster resources | cut -f 1 -d ' ' | tail -n $count)
}

resourceList1()
{
	echo $( cluster status | cut -d' ' -f 1 )
}

onlineResource()
{
	echo $( cluster status | tr -s ' ' | awk '$2=="Running" {print $1}' )
}

offlineResource()
{
	echo $( cluster status | tr -s ' ' | awk '$2=="Offline" {print $1}' )
}

comatoseResource()
{
        echo $( cluster status | tr -s ' ' | awk '$2=="Comatose" {print $1}' )
}

liveNodes()
{
	echo $(cluster view | grep 'Cluster nodes' | sed -e 's/\[\(.*\)\]/\1/' -e 's/\Cluster nodes/''/g; s/\,/''/g; s/\t  /''/g')
}

preNodeName()
{
	lns_pre=($(cluster preferred_nodes ${prev} | wc -l))
	count2=$((lns_pre-1))
	echo $(cluster preferred_nodes ${prev} | tail -n $count2)
}

unaNodeName()
{
	lns_una=($(cluster unassigned_nodes ${prev} | wc -l))
	count_una=$((lns_una-1))
	echo $(cluster unassigned_nodes ${prev} | tail -n $count_una)
}

preferredLivenodes()
{
	live_node=($( liveNodes ))
	pre_node_name=($( preNodeName ))
	un_node_name=($( unaNodeName ))
	node_name2=()
	total_nodes=(${pre_node_name[*]} ${un_node_name[*]})
	for i in ${total_nodes[*]}
	do
		str=$(compgen -W "${live_node[*]}" $i)
		if [ -z "$str" ]
		then
			str=""
		else
			node_name2+=($i)
		fi
	done

	echo ${node_name2[*]}
}
_cluster()
{
	tst=($(cluster resources))
	if [ $? -ne 0 ]
	then
		return
	fi
	cur=${COMP_WORDS[COMP_CWORD]}
	prev=${COMP_WORDS[COMP_CWORD - 1]}
	preprev=${COMP_WORDS[COMP_CWORD - 2]}
	preprev2=${COMP_WORDS[COMP_CWORD - 3]}

	case ${preprev2} in
	esac

	case ${preprev} in
		script)
			resList2=($(resourceList2))
			COMPREPLY=($(compgen -W "${resList2[*]}" -- $cur))
			;;
		alert)
			alert=(yes no)
			COMPREPLY=($(compgen -W "${alert[*]}" -- $cur))
			;;
		monitor)
			monitor=(status start stop)
			COMPREPLY=($(compgen -W "${monitor[*]}" -- $cur))
			;;
		convert)
			resList=($( resourceList1 ))
			if [ "$prev" == "preview" ];
			then
				COMPREPLY=($(compgen -W "${resList[*]}" -- $cur))
			fi
			;;
		migrate)
			node_names=($(preferredLivenodes))
			migrate=(-l -list -m -most -n -next ${node_names[*]})
			COMPREPLY=($(compgen -W "${migrate[*]}" -- $cur))
			;;
		online)
			node_names=($(preferredLivenodes))
			COMPREPLY=($(compgen -W "${node_names[*]}" -- $cur))
			;;

	esac

	case ${prev} in
		resources)
			resopt=(-a -i -v -c -p -u)
			COMPREPLY=($(compgen -W "${resopt[*]}" -- $cur))
			;;
		resource)
                        resList2=($(resourceList2))
			COMPREPLY=($(compgen -W "${resList2[*]}" -- $cur))
			;;
		resource-policy)
			resList2=($(resourceList2))
			COMPREPLY=($(compgen -W "${resList2[*]}" -- $cur))
			;;
		resource-protocol)
			resList2=($(resourceList2))
			COMPREPLY=($(compgen -W "${resList2[*]}" -- $cur))
			;;
		script)
			scriptType=(load-script unload-script monitor-script all)
			COMPREPLY=($(compgen -W "${scriptType[*]}" -- $cur))
			;;
		unassigned_nodes)
			resList2=($(resourceList2))
			COMPREPLY=($(compgen -W "${resList2[*]}" -- $cur))
			;;
		preferred_nodes)
			resList2=($(resourceList2))
			COMPREPLY=($(compgen -W "${resList2[*]}" -- $cur))
			;;
		connections)
			connections=(-a)
			COMPREPLY=($(compgen -W "${connections[*]}" -- $cur))
			;;
		stats)
			stats=(display clear)
			COMPREPLY=($(compgen -W "${stats[*]}" -- $cur))
			;;
		set)
			set=(ipaddress port quorum quorumwait heartbeat tolerance masterwatchdog slavewatchdog maxretransmits enableemail emailaddresses emailoptions resourcepriority)

			COMPREPLY=($(compgen -W "${set[*]}" -- $cur))
			;;
		maintenance)
			maintenance=(on off)
			COMPREPLY=($(compgen -W "${maintenance[*]}" -- $cur))
			;;
		info)
			info=(all basic notification priority protocol summary)
			COMPREPLY=($(compgen -W "${info[*]}" -- $cur))
			;;
		convert)
			convert=(preview commit)
			COMPREPLY=($(compgen -W "${convert[*]}" -- $cur))
			;;
		monitor)
			resList=($( resourceList1 ))
			COMPREPLY=($(compgen -W "${resList[*]}" -- $cur))
			;;
		alert)
			resList=($( resourceList1 ))
			COMPREPLY=($(compgen -W "${resList[*]}" -- $cur))
			;;
		migrate)
			online_resource=($( onlineResource ))
			COMPREPLY=($(compgen -W "${online_resource[*]}" -- $cur))
			;;
		status)
			resList=($( resourceList1 ))
			COMPREPLY=($(compgen -W "${resList[*]}" -- $cur))
			;;
		online)
			offline_resource=($( offlineResource ))
			COMPREPLY=($(compgen -W "${offline_resource[*]}" -- $cur))
			;;
		offline)
			online_resource=($( onlineResource )  $( comatoseResource))
			COMPREPLY=($(compgen -W "${online_resource[*]}" -- $cur))
			;;
		rename)
			offline_resource=($( offlineResource))
			COMPREPLY=($(compgen -W "${offline_resource[*]}" -- $cur))
			;;
		cluster)
			option1=(resource resource-policy resource-protocol script unassigned_nodes restart set stats enable resetresources)
			option2=(preferred_nodes help alert convert down migrate monitor offline status view connections nsmi)
			option3=(exec info join leave maintenance online pools rename resources credentials disable refresh scan)
			options=(${option1[*]} ${option2[*]} ${option3[*]})
			COMPREPLY=($(compgen -W "${options[*]}" -- $cur))
			;;
	esac

}


check_version()
{
	bash_version_major=$( echo ${BASH_VERSION} | cut -f 1 -d'.')
	bash_version_minor=$( echo ${BASH_VERSION} | cut -f 2 -d'.')

	if [[ ( $((${bash_version_major})) -ge 4 ) && ( $((${bash_version_minor})) -ge 4 ) ]];
	then
		return 0
	else
		return 1
	fi
}


check_version && SORTOPTION="-o nosort" || SORTOPTION=""
complete ${SORTOPTION} -F _cluster cluster
