#****************************************************************************
#
# Copyright (c) 2006 - 2007 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:	Novell, Inc.
#  Workfile:	ClusterCliSnapin_Connections.pm
#  Contents:	Command line implementation for Novell Cluster Services
#			and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Connections;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;
use Getopt::Long;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("connections");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	my ($self) = @_;

	my $host = $self->GetHost();

	if (!$self->IsBCCLoaded($host))
	{
		$self->Help();
		return(0);
	} # if (!$self->IsBCCLoaded($host))

	console_print("\n");

	my $all_clusters = 0;

	my %opts = ('a' => \$all_clusters);
	Getopt::Long::Configure("permute");
	Getopt::Long::Configure("pass_through");
	GetOptions(%opts);

	return($self->ShowClusterConnections($all_clusters));
} # Execute

#**********************************************************************
# Name:		ShowClusterConnections
# Description:	Display connection status for all peer clusters
# Parameters:
# Return:	true on success.  false otherwise.
# Notes:
##**********************************************************************
sub ShowClusterConnections($)
{
	my ($self, $all_clusters) = @_;

	my $xml;
	my $host;
	my $cluster_name;
	my $fh;
	my %params;
	my @peerlist;

	# Get list of peer clusters

	$host = $self->GetHost();
	$cluster_name = $self->GetClusterName($host);

	if ($cluster_name eq "") {
		console_print("There was an error retrieving the cluster name from NCS.  If the error\n");
		console_print("persists, please contact Novell Technical Support\n");
		return(0);
	}

	if ($all_clusters)
	{
		$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>" .
			"<bccRequest><bccConfig><getPeerData/></bccConfig></bccRequest>";
		log_request($xml);

		$fh = $self->OpenVfsFile($host, "/Novell/Cluster/BCC_Config.cmd");
		$self->WriteVfsFile($fh, $xml);
		$self->ReadVfsFile($fh, $xml);
		$self->CloseVfsFile($fh);

		log_response($xml);

		$self->ParseBccResults($xml, \%params, "bccConfig", "getPeerData");
		if (0 == $params{"BccReplyCode"})
		{
			if ($xml =~ /<bccReply>[\s]*<bccConfig>[\s]*<getPeerData>[\s]*<peers>(.*?)<\/peers>.*?<\/getPeerData>[\s]*<\/bccConfig>[\s]*<\/bccReply>/s)
			{
				$xml = $1;
				@peerlist = sort($xml =~ /<peer>.*?<cluster>(.*?)<\/cluster>.*?<\/peer>/gs);
			}
		}
		else
		{
			console_print("$params{\"BccReplyString\"} ($params{\"BccReplyCode\"})\n");
			return(0);
		}
	}
	else
	{
		@peerlist = ($cluster_name);
	}

	for (my $idx = 0; $idx < @peerlist; $idx++)
	{
		my $cluster = $peerlist[$idx];

		$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>";
		$xml .= "<bccRequest><bccManage><getConnections><cluster>$cluster</cluster></getConnections></bccManage></bccRequest>";

		log_request($xml);

		$fh = $self->OpenVfsFile($host, "/Novell/Cluster/BCC_Manage.cmd");
		$self->WriteVfsFile($fh, $xml);
		$self->ReadVfsFile($fh, $xml);
		$self->CloseVfsFile($fh);

		log_response($xml);

		$self->ParseBccResults($xml, \%params, "bccManage", "getConnections");
		console_print("Connection status for cluster: $cluster".($all_clusters && $cluster eq $cluster_name ? " (this cluster)" : "")."\n");
		if (0 == $params{"BccReplyCode"})
		{
			my $peer = "Cluster Name";
			my $username = "Username";
			my $status = "Connection Status";
			my $format = "  @<<<<<<<<<<<<<<<<<<<<<<<< @<<<<<<<<<<<<<<<<<<<<<<<< @>>>>>>>>>>>>>>>>>> \n";
			# Clear the format output accumulator
			$^A = "";
			formline($format, ($peer,$username,$status));
			my @connections = $self->SortByElement("cluster", "", $xml =~ /<connection>(.*?)<\/connection>/gs);
			foreach $xml (@connections)
			{
				$peer = "<unknown>";
				$username = "<unknown>";
				$status = "<unknown>";

				if ($xml =~ /<cluster>(.*?)<\/cluster>/s)
				{
					$peer = $1;
				} # if ($xml =~ /<cluster>(.*?)<\/cluster>/s)
	
				if ($xml =~ /<username>(.*?)<\/username>/s)
				{
					$username = $1;
				} # if ($xml =~ /<username>(.*?)<\/username>/s)
	
				if ($xml =~ /<status>(.*?)<\/status>/s)
				{
					if ($1 eq "cannotConnect")
					{
						$status = "Cannot Connect";
					}
					elsif ($1 eq "invalidCredentials")
					{
						$status = "Invalid Credentials";
					}
					elsif ($1 eq "authenticating")
					{
						$status = "Authenticating";
					}
					elsif ($1 eq "notAuthorized")
					{
						$status = "Not Authorized";
					}
					elsif ($1 eq "unknown")
					{
						$status = "Unknown";
					}
					elsif ($1 eq "okay")
					{
						$status = "OK";
					}
					else
					{
						$status = $1;
					} # if ($1 eq "cannotConnect")
				} # if ($xml =~ /<status>(.*?)<\/status>/s)
	
				formline($format, ($peer,$username,$status));
			} # foreach $xml (@connections)
			console_print($^A);
		}
		else
		{
			console_print("$params{\"BccReplyString\"} ($params{\"BccReplyCode\"})\n");
		} # if (0 == $params{"bccResponseCode"})
	}
	return(1);
} # sub ShowClusterConnections($)

#**********************************************************************
# Name:			Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("\nCLUSTER CONNECTIONS\n");
	console_print("  Show Business Continuity Cluster peer connection status.\n");
	console_print("  The following are valid parameters to the connections command:\n");
	console_print("  -a: Retrieve connection status from all peer clusters.\n");
	console_print("      If this option is not specified, only the connections\n");
	console_print("      for the local cluster are displayed.\n");
	console_print("Example: cluster connections -a\n");
	console_print("NOTE: This is a Business Continuity Cluster command.\n");

	return(1);

} # Help

1;

