#****************************************************************************
#
# Copyright (c) 2004 - 2005 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Down.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Down;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("down");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	my ($self, $seconds) = @_;
	my $fh;
	my $host;
	my $xml;

	if( ! defined( $seconds ) || '-y' ne $seconds )
        {
		my $ack;

		console_print( "\nWARNING!\n\n" );
		console_print( "  This command will force all the nodes currently\n" );
		console_print( "  in the cluster to leave and may result in interruptions\n" );
		console_print( "  to the applications and services managed by Novell\n" );
		console_print( "  Cluster Services.\n\n" );
		console_print( "Are you sure you want to shut down the cluster (yes/no)? " );
		$ack = console_getstring();
		if( 'yes' ne $ack )
		{
			console_print("\nOperation cancelled.\n");
			return( 1 );
		}
	}
	$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>";
	$xml .= "<ncsRequest><down/></ncsRequest>";

	log_request($xml);

	# Output the standard NCS information
	$host = $self->GetHost();
   $fh = $self->OpenVfsFile($host, "/Novell/Cluster/Cluster.cmd");
	$self->WriteVfsFile($fh, $xml);
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	log_response($xml);

	# The grouping must be a minimal match because sometimes sysread returns
	# the XML twice.  Don't ask me why...
	$xml =~ /<ncsReply>[\s]*<failed>(.*?)<\/failed>[\s]*<\/ncsReply>/s;
	$xml = $1;

	if ($xml)
	{
		console_print("There was an error while downing the cluster\n");
		console_print("Error: \"$xml\"\n");
	} # if ($xml)
	
	return(1);

} # Execute

#**********************************************************************
# Name:			Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("\nCLUSTER DOWN\n");
	console_print("  Used to down the current cluster membership.\n");
	console_print("  Will take every node out of the cluster as if CLUSTER\n");
	console_print("  LEAVE had been executed by all cluster members.\n");
	console_print("Example: cluster down\n");

	return(1);

} # Help

1;

