#****************************************************************************
#
# Copyright (c) 2003 - 2007 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Enable.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Enable;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;
use POSIX;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("enable");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	my $self = shift;
	my $params;

	if ( defined $_[0] && $_[0] ne "-q")
	{
		$params = lc(shift);
		$self->EnableResource($params);
	}
	else
	{
		if (is_netware())
		{
			$self->EnableClusterNW();			
		}
		else
		{
			$self->EnableCluster();
		} # if (is_netware())
	} # if ($params && $params ne "-q")

	return(1);

} # Execute

#**********************************************************************
# Name:			EnableResource
# Description:	Enables the specified resource
# Parameters:	string	- Resource to enable
# Return:		None
# Notes:
#**********************************************************************
sub EnableResource($)
{
	my $self = shift;
	my $resource = lc(shift);
	my $xml;
	my @peerList;
	my $peerXml = "";
	my $peer;
	my $fh;
	my $host;
	my %params;
	my %results;

	$host = $self->GetHost();

	# Get the list of peer names
	$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>" .
		"<bccRequest><bccConfig><getPeerData/></bccConfig></bccRequest>";

	log_request($xml);

	$fh = $self->OpenVfsFile($host, "/Novell/Cluster/BCC_Config.cmd");
	$self->WriteVfsFile($fh, $xml);
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	log_response($xml);

	$self->ParseBccResults($xml, \%params, "bccConfig", "getPeerData");

	if (0 == $params{"BccReplyCode"})
	{
		if ($xml =~ /<bccReply>[\s]*<bccConfig>[\s]*<getPeerData>[\s]*<peers>(.*?)<\/peers>.*?<\/getPeerData>[\s]*<\/bccConfig>[\s]*<\/bccReply>/s)
		{
			$xml = $1;
			@peerList = $xml =~ /<peer>.*?<cluster>(.*?)<\/cluster>.*?<\/peer>/gs;

			foreach $peer (@peerList)
			{
				$peerXml .= "<peer><cluster>$peer</cluster></peer>";				
			} # foreach $peer (@peerList)			
		} # if ($xml =~ /.../s)
	}
	else
	{
		console_print("There was an error retrieving the list of peer clusters.  If the\n");
		console_print("problem persists please contact Novell Technical Support.\n");
		return;
	} # if (0 == $params{"BccReplyCode"})

	# Get the attributes of the given resource
	$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>" .
		"<bccRequest><bccConfig><getResourceInfo>" .
		"<name>$resource</name>".
		"</getResourceInfo></bccConfig></bccRequest>";

	log_request($xml);
	
	$fh = $self->OpenVfsFile($host, "/Novell/Cluster/BCC_Config.cmd");
	$self->WriteVfsFile($fh, $xml);
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	log_response($xml);

	# Save the attributes that need to be returned in the actual enable command.
	# The grouping must be a minimal match because sometimes sysread returns
	# the XML twice.  Don't ask me why...
	$xml =~ /<getResourceInfo>(.*?)<\/getResourceInfo>/s;
	if ($1)
	{
		$xml = $1;

		# Remove the <enabled/> tag if it exists
		$xml =~ /(.*)<enabled\/>(.*)/s;
		if ($1 || $2)
		{
			$xml = "";
			if ($1)
			{
				$xml .= $1;				
			} # if ($1)

			if ($2)
			{
				$xml .= $2;				
			} # if ($2)			
		} # if ($1 || $2)

		# Remove the <result> tags if they exist
		$xml =~ /(.*)<result.*>.*<\/result>(.*)/s;
		if ($1 || $2)
		{
			$xml = "";
			if ($1)
			{
				$xml .= $1;				
			} # if ($1)

			if ($2)
			{
				$xml .= $2;				
			} # if ($2)			
		} # if ($1 || $2)

		# Format the XML for the actual enable command
		$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>" .
			"<bccRequest><bccConfig><setResourceInfo>" .
			"<enabled/>" .
			"<peers>$peerXml</peers>" .
			"$xml" .
			"</setResourceInfo></bccConfig></bccRequest>";

		log_request($xml);

		# Write the command
		$fh = $self->OpenVfsFile($host, "/Novell/Cluster/BCC_Config.cmd");
		$self->WriteVfsFile($fh, $xml);

		# Get the result
		$self->ReadVfsFile($fh, $xml);
		$self->CloseVfsFile($fh);

		log_response($xml);

		# Output the results
		$self->ParseBccResults($xml, \%results, "bccConfig", "setResourceInfo");
		console_print("\n$results{\"BccReplyString\"} ($results{\"BccReplyCode\"})\n");

		return;
	} # if ($1)

	console_print("There was an error retrieving the resource data.  If the\n");
	console_print("problem persists please contact Novell Technical Support.\n");

} # EnableResource

#**********************************************************************
# Name:			EnableCluster
# Description:	Enables the cluster on everything but NetWare
# Parameters:	None
# Return:		None
# Notes:
#**********************************************************************
sub EnableCluster()
{
	my $self = shift;
	my $xml;
	my $fh;
	my $host;
	my $prompt;
	my %results;

	console_print("Are you sure you want to enable BCC services on this cluster (Y/N)? ");
	$prompt = console_getstring();

	# See what the user wants to do
	if (uc(substr($prompt, 0, 1)) ne "Y")
	{
		# The user cancelled the operation
		return;
	} # if (uc(substr($prompt, 0, 1)) ne "Y")

	# The user wants to continue the operation
	$host = $self->GetHost();

	# Get the attributes of the cluster
	$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>" .
		"<bccRequest><bccConfig><getClusterInfo/></bccConfig></bccRequest>";

	log_request($xml);
	
	$fh = $self->OpenVfsFile($host, "/Novell/Cluster/BCC_Config.cmd");
	$self->WriteVfsFile($fh, $xml);
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	log_response($xml);

	# Save the attributes that need to be returned in the actual enable command.
	# The grouping must be a minimal match because sometimes sysread returns
	# the XML twice.  Don't ask me why...
	$xml =~ /<getClusterInfo>(.*?)<\/getClusterInfo>/s;
	if ($1)
	{
		$xml = $1;

		# Remove the <enabled/> tag if it exists
		$xml =~ /(.*)<enabled\/>(.*)/s;
		if ($1 || $2)
		{
			$xml = "";
			if ($1)
			{
				$xml .= $1;				
			} # if ($1)

			if ($2)
			{
				$xml .= $2;				
			} # if ($2)			
		} # if ($1 || $2)

		# Remove the <result> tags if they exist
		$xml =~ /(.*)<result.*>.*<\/result>(.*)/s;
		if ($1 || $2)
		{
			$xml = "";
			if ($1)
			{
				$xml .= $1;				
			} # if ($1)

			if ($2)
			{
				$xml .= $2;				
			} # if ($2)			
		} # if ($1 || $2)

		# Format the XML for the actual enable command
		$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>" .
			"<bccRequest><bccConfig><setClusterInfo>" .
			"<enabled/>" .
			"$xml" .
			"</setClusterInfo></bccConfig></bccRequest>";

		log_request($xml);

		# Write the command
		$fh = $self->OpenVfsFile($host, "/Novell/Cluster/BCC_Config.cmd");
		$self->WriteVfsFile($fh, $xml);

		# Get the result
		$self->ReadVfsFile($fh, $xml);
		$self->CloseVfsFile($fh);

		log_response($xml);

		# Output the results
		$self->ParseBccResults($xml, \%results, "bccConfig", "setClusterInfo");
		console_print("\n$results{\"BccReplyString\"} ($results{\"BccReplyCode\"})\n");

		return;
	} # if ($1)

	console_print("There was an error retrieving the cluster data.  If the\n");
	console_print("problem persists please contact Novell Technical Support.\n");

} # EnableCluster

#**********************************************************************
# Name:			EnableClusterNW
# Description:	Enables the cluster on NetWare
# Parameters:	None
# Return:		None
# Notes:
#**********************************************************************
sub EnableClusterNW()
{
	my $self = shift;
	my $xml;
	my $fh;
	my $host;
	my $prompt;
	my %results;

	$host = $self->GetHost();

	# Parse for the prompt
	for (my $idx = 0; $idx < $#ARGV + 1; $idx++)
	{
		if ($ARGV[$idx] eq "-q")
		{
			$prompt = $ARGV[$idx + 1];
			last;
		} # if ($ARGV[$idx] eq "-q")
	} # for (my $idx = 0; $idx < $#ARGV + 1; $idx++)

	if (!defined($prompt))
	{
		# Prompt the user if the operation is OK
		$xml = "<query>" .
					"<input>" .
						"<prompt>Are you sure you want to enable BCC services on this cluster (Y/N)? </prompt>" .
						"<flag>-q</flag>" .
					"</input>" .
				"</query>";

		console_print($xml);
		return;
	}
	else
	{
		# See what the user wants to do
		if (uc(substr($prompt, 0, 1)) ne "Y")
		{
			# The user cancelled the operation
			return;
		} # if (uc(substr($prompt, 0, 1)) ne "Y")
	} # if (!defined($prompt))

	# The user wants to continue the operation
	# Get the attributes of the cluster
	$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>" .
		"<bccRequest><bccConfig><getClusterInfo/></bccConfig></bccRequest>";

	log_request($xml);
	
	$fh = $self->OpenVfsFile($host, "/Novell/Cluster/BCC_Config.cmd");
	$self->WriteVfsFile($fh, $xml);
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	log_response($xml);

	# Save the attributes that need to be returned in the actual enable command.
	# The grouping must be a minimal match because sometimes sysread returns
	# the XML twice.  Don't ask me why...
	$xml =~ /<getClusterInfo>(.*?)<\/getClusterInfo>/s;
	if ($1)
	{
		$xml = $1;

		# Remove the <enabled/> tag if it exists
		$xml =~ /(.*)<enabled\/>(.*)/s;
		if ($1 || $2)
		{
			$xml = "";
			if ($1)
			{
				$xml .= $1;				
			} # if ($1)

			if ($2)
			{
				$xml .= $2;				
			} # if ($2)			
		} # if ($1 || $2)

		# Remove the <result> tags if they exist
		$xml =~ /(.*)<result.*>.*<\/result>(.*)/s;
		if ($1 || $2)
		{
			$xml = "";
			if ($1)
			{
				$xml .= $1;				
			} # if ($1)

			if ($2)
			{
				$xml .= $2;				
			} # if ($2)			
		} # if ($1 || $2)

		# Format the XML for the actual enable command
		$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>" .
			"<bccRequest><bccConfig><setClusterInfo>" .
			"<enabled/>" .
			"$xml" .
			"</setClusterInfo></bccConfig></bccRequest>";

		log_request($xml);

		# Write the command
		$fh = $self->OpenVfsFile($host, "/Novell/Cluster/BCC_Config.cmd");
		$self->WriteVfsFile($fh, $xml);

		# Get the result
		$self->ReadVfsFile($fh, $xml);
		$self->CloseVfsFile($fh);

		log_response($xml);

		# Output the results
		$self->ParseBccResults($xml, \%results, "bccConfig", "setClusterInfo");
		console_print("\n$results{\"BccReplyString\"} ($results{\"BccReplyCode\"})\n");

		return;
	} # if ($1)

	console_print("There was an error retrieving the cluster data.  If the\n");
	console_print("problem persists please contact Novell Technical Support.\n");

} # EnableClusterNW

#**********************************************************************
# Name:			Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("\nCLUSTER ENABLE {resource}\n");
	console_print("  Enables Business Continuity Clustering for the specified resource.\n");
	console_print("  By default, the preferred peers list for the resource is configured\n");
	console_print("  to include all peer clusters in the Business Continuity Cluster.  The\n");
	console_print("  local cluster must be a member of a cluster that has already been enabled\n");
	console_print("  for Business Continuity Clustering.  If no resource is specified then the\n");
	console_print("  cluster itself is enabled for Business Continuity Clustering.\n");
	console_print("Example: cluster enable res1\n");

	return(1);

} # Help

1;

