#****************************************************************************
#
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Exec.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Exec;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("exec");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	my $self = $_[0];
	my $cmd = join( ' ', @_[1..$#_] );
	my $fh;
	my $host;
	my $xml;

	if (!defined($cmd) || !$cmd)
	{
		console_print("\nYou must specify a command to execute on the cluster nodes.\n");
		console_print("Type \"cluster help exec\" for help.\n");
		return(1);		
	} # if (!defined($cmd) || !$cmd)

	$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>";
	$xml .= "<ncsRequest><exec>$cmd</exec></ncsRequest>";

	log_request($xml);

	# Output the standard NCS information
	$host = $self->GetHost();
	$fh = $self->OpenVfsFile($host, "/Novell/Cluster/Cluster.cmd");
	$self->WriteVfsFile($fh, $xml);
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	log_response($xml);

	# The grouping must be a minimal match because sometimes sysread returns
	# the XML twice.  Don't ask me why...
	$xml =~ /<ncsReply>[\s]*<failed>(.*?)<\/failed>[\s]*<\/ncsReply>/s;
	$xml = $1;

	if ($xml)
	{
		console_print("There was an error performing the \"cluster exec\" command.\n");
		console_print("Error: \"$xml\"\n");
	} # if ($xml)

	return(1);

} # Execute

#**********************************************************************
# Name:			Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("\nCLUSTER EXEC\n");
	console_print("  Execute remainder of command on All Nodes in the Cluster.\n");
	console_print("NetWare Example: cluster exec alias name value\n");
	# Fix for Bug 446714 - HELP screen for CLUSTER EXEC command is not correct : Prashant 21 Nov 2008.
	console_print("Linux Example: cluster exec \"command\" \n");

	return(1);

} # Help

1;

