#****************************************************************************
#
# © Copyright 2021 Micro Focus or one of its affiliates.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:    ClusterCliSnapin_Homogeneous.pm
#  Contents:    Command line implementation for Novell Cluster Services
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Homogeneous;

use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

sub Param()
{
	return("homogeneous");
} # Param

# Returns 1 if the cluster is above the specified version, else 0
sub Execute(@)
{
	my ($self, $version) = @_;
	my $xml;
	my $err;
	my $host;
	my $fh;
	my $is_homogeneous;
	my $vfsfile = "/Novell/Cluster/ClusterManage.cmd";
	my @valid_versions = ("OES2023", "OES2018SP3", "OES2018SP2", "OES2018", "OES2015SP1", "OES2015");

	$version = uc $version;

	# OES2018SP1 is not included in valid versions because the kernel space code
	# does not check for it as the signature for 2018 and 2018SP1 are the same.
	if ( !(grep { $_ eq $version} @valid_versions) )
	{
		console_print("Please specify a valid version.\n");
		return(0);
	}

	$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>";
	$xml .= "<ncsRequest><clusterManage><InfoclusterVersion>";
	$xml .= "<version>".$version."</version>";
	$xml .= "</InfoclusterVersion></clusterManage></ncsRequest>";

	$host = $self->GetHost();
	$fh = $self->OpenVfsFile($host, $vfsfile);
	$self->WriteVfsFile($fh, $xml);
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	$xml =~ /<result value=\"(.*?)\">/s;
	$err = $1;
	if(defined($err) && $err == 0)
	{
		$xml =~ /<SafeToUpgradeFS>(.*?)<\/SafeToUpgradeFS>/s;
		$is_homogeneous = $1;
		if($is_homogeneous eq "yes")
		{
			console_print("All nodes of the cluster are above $version.\n");
		        return(1);
		}
		else
		{
			console_print("Not all nodes of the cluster are above $version.\n");
			return(0);
		}
	}

	console_print("Error while retrieving the homogeneity of the cluster.\n");
	return(0);
}

sub Help(@)
{
	console_print("\nCLUSTER HOMOGENEOUS {VERSION}\n");
	console_print(" Checks if all the nodes of the cluster are above the specified version.\n");
	console_print("Example: cluster homogeneous OES2018SP3\n");

	return(1);
}
