#****************************************************************************
#
# Copyright (c) 2003 - 2005 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Info.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Info;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("info");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	my $self = shift;
	my $verb;
	my $fh;
	my $host;
	my $xml;
	my $vfsfile	= "/Novell/Cluster/ClusterConfig.cmd";
	my $dosummary;

	if (!defined $_[0])
	{
		$verb = "";
	}
	else
	{
		$verb = lc(shift);
	}

	if ($verb eq "all")
	{
		$verb = "";
	}
	elsif ($verb eq "basic")
	{
		$verb = "<typeOfInfo><basicInfo/></typeOfInfo>";
	}

	elsif ($verb eq "notification")
	{
		$verb = "<typeOfInfo><notificationInfo/></typeOfInfo>";
	}
	elsif ($verb eq "priority")
	{
		$verb = "<typeOfInfo><priorityInfo/></typeOfInfo>";
	}
	elsif ($verb eq "protocol")
	{
		$verb = "<typeOfInfo><protocolInfo/></typeOfInfo>";
	}
	elsif ($verb eq "summary")
	{
		$verb = "<typeOfInfo><protocolInfo/></typeOfInfo>";
		$dosummary = "yes"
	}
	else
	{
		console_print("\nInvalid paramemter \"$verb\"\n");
		$self->Help();
		return(1);
	} # if ($verb eq "all")

	$xml	= "<virtualIO><datastream name=\"command\"/></virtualIO>";
	$xml	.= "<ncsRequest><clusterConfig><getClusterInfo>";
	$xml	.= $verb;
	$xml	.= "</getClusterInfo></clusterConfig></ncsRequest>";

	# Send the command and read the result
	$host = $self->GetHost();
	$fh = $self->OpenVfsFile($host, $vfsfile);
	$self->WriteVfsFile($fh, $xml);
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	# The grouping must be a minimal match because sometimes sysread returns
	# the XML twice.  Don't ask me why...
	$xml =~ /<ncsReply>[\s]*<clusterConfig>[\s]*<getClusterInfo>(.*?)<\/getClusterInfo>[\s]*<\/clusterConfig>[\s]*<\/ncsReply>/s;
	$xml = $1;

	# Parse for and return the Basic info
	if ($xml =~ /<basicInfo>(.*?)<\/basicInfo>/s)
	{
      my $basic = $1;
		my $name = "<unknown>";
		my $ip = "<unknown>";
		my $port = "<unknown>";
		my $timeout = "<unknown>";
		my $membership = "<unknown>";

      if ($basic =~ /<name>(.*?)<\/name>/s)
		{
			$name = $1;
		}
		if ($basic =~ /<ipAddress>(.*?)<\/ipAddress>/s)
		{
			$ip = $1;
		}
		if ($basic =~ /<port>(.*?)<\/port>/s)
		{
			$port = $1;
		}
		if ($basic =~ /<timeout>(.*?)<\/timeout>/s)
		{
			$timeout = $1;
		}
		if ($basic =~ /<membership>(.*?)<\/membership>/s)
		{
			$membership = $1;
		}

		console_print("\n\tCluster: $name, Management address: $ip:$port\n");
		console_print("\tQuorum timeout: $timeout seconds, Quorum membership: $membership\n");
	} # if ($xml =~ /<basicInfo>(.*?)<\/basicInfo>/s)

	# Parse for and return the Notification info
	if ($xml =~ /<notificationInfo state=\"(.*?)\">(.*?)<\/notificationInfo>/s)
   {
		my $state = $1;
      my $notification = $2;
		my $email;
		my @emaillist;
		my $type = "<unknown>";
		my $xmlmsg;

      $notification =~ /<emailAddresses>(.*?)<\/emailAddresses>/s;
		$email = $1;
		@emaillist = $email =~ /<email>(.*?)<\/email>/gs;

		if ($notification =~ /<notificationType>(.*?)<\/notificationType>/s)
		{
			$type = $1;
			if ($type =~ /.*<onlyCritical\/>.*/)
			{
				$type = "Critical";
			}
			elsif ($type =~ /.*<verbose\/>.*/)
			{
				$type = "Verbose";
			}
		}

		if ($notification =~ /.*<xmlMsg\/>.*/s)
		{
			$xmlmsg = "Yes";
		}
		else
		{
			$xmlmsg = "No";
		}

		console_print("\n\tE-mail notification is $state\n");
		console_print("\tMessage detail: $type, XML messages: $xmlmsg\n");
		console_print("\tConfigured e-mail addresses:\n");

		foreach $email (@emaillist)
      {
			console_print("\t\t$email\n");
		} # foreach $email (@emaillist)
	} # if ($xml =~ /<notificationInfo state=\"(.*?)\">(.*?)<\/notificationInfo>/s)

	# Parse for and return the Priority info
	if ($xml =~ /<priorityInfo>(.*?)<\/priorityInfo>/s)
   {
		my $priority = $1;
		my $resource;
		my @resourcelist;

      $priority =~ /<resourceList>(.*?)<\/resourceList>/s;
		$resource = $1;
		@resourcelist = $resource =~ /<name>(.*?)<\/name>/gs;

		console_print("\n\tResource priority list (highest to lowest):\n");

		foreach $resource (@resourcelist)
      {
			console_print("\t\t$resource\n");
		} # foreach $resource (@resourcelist)
	} # if ($xml =~ /<notificationInfo state=\"(.*?)\">(.*?)<\/notificationInfo>/s)

	# Parse for and return the Protocol info
	if ($xml =~ /<protocolInfo>(.*?)<\/protocolInfo>/s)
	{
      my $protocol = $1;
		my $heartbeat = "<unknown>";
		my $tolerance = "<unknown>";
		my $masterwatchdog = "<unknown>";
		my $slavewatchdog = "<unknown>";
		my $maxretransmits = "<unknown>";
		my $summary = "<unknown>";

		if ($protocol =~ /<heartbeat>(.*?)<\/heartbeat>/s)
		{
			$heartbeat = $1;
		}
		if ($protocol =~ /<tolerance>(.*?)<\/tolerance>/s)
		{
			$tolerance = $1;
		}
		if ($protocol =~ /<masterWatchdog>(.*?)<\/masterWatchdog>/s)
		{
			$masterwatchdog = $1;
		}
		if ($protocol =~ /<slaveWatchdog>(.*?)<\/slaveWatchdog>/s)
		{
			$slavewatchdog = $1;
		}
		if ($protocol =~ /<maxRetransmits>(.*?)<\/maxRetransmits>/s)
		{
			$maxretransmits = $1;
		}
		if ($protocol =~ /<summary>(.*?)<\/summary>/sm)
		{
			$summary = $1;
		}

		if ($dosummary)
		{
         console_print("\n$summary\n");	
		}
		else
		{
			console_print("\n\tCluster protocol internals\n");
			console_print("\tHeartbeat: $heartbeat, Tolerance: $tolerance\n");
			console_print("\tMaster Watchdog: $masterwatchdog, Slave Watchdog: $slavewatchdog\n");
			console_print("\tMax Retransmits: $maxretransmits\n");
		} # if ($dosummary)
	} # if ($xml =~ /<protocolInfo>(.*?)<\/protocolInfo>/s)

	return(1);

} # Execute

#**********************************************************************
# Name:			Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("\nCLUSTER INFO {ALL, BASIC, NOTIFICATION, PRIORITY, PROTOCOL, SUMMARY}\n");
	console_print("  Used to view information on the cluster configuration.\n");
	console_print("  ALL displays BASIC, NOTIFICATION, PRIORITY, and PROTOCOL settings\n");
	console_print("  BASIC displays ip address, port, and quorum settings\n");
	console_print("  NOTIFICATION displays the e-mail notification settings\n");
	console_print("  PRIORITY displays the resource priority list\n");
	console_print("  PROTOCOL displays the cluster protocol settings\n");
	console_print("  SUMMARY displays the cluster protocol summary\n");
	console_print("Example: cluster info protocol\n");

	return(1);

} # Help

1;

