#****************************************************************************
#
# Copyright (c) 2003 - 2010 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Monitor.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Monitor;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("monitor");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	if( 3 > scalar( @_ ))
	{
		Help();
		return 0;
	}

	console_print( `/opt/novell/ncs/bin/ncs-resourced.py monitor $_[1] $_[2] 2>/dev/null` );

	return 1;
} # Execute

#**********************************************************************
# Name:                 Help
# Description:  Prints help for the command handler
# Parameters:   List of parameters passed in to the help command
# Return:               true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
        console_print("\nCLUSTER MONITOR RESOURCE_NAME {status|start|stop}\n");
        console_print("  Used to manually start, stop or check the status of resource monitoring.\n");
        console_print("  The resource must be running on this node.\n");
        console_print("  Resource monitoring must be enabled for the resource.\n");
        console_print("Example: cluster monitor shd_pool_res_01 status\n");

        return(1);

} # Help

1;

