#****************************************************************************
#
# Copyright (c) 2003 - 2005 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Online.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Online;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("online");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
   my ($self, $resource, $node) = @_;
	my $fh;
	my $host;
	my $xml;
	my %results;

	if (!$resource)
	{
		$self->Help();
		return(0);
	} # if (!$resource)
	$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>";
	$xml .= "<ncsRequest><clusterManage><controlResource>";
	$xml .= "<name>$resource</name><action><online/></action>";

	if ($node)
	{
		if ("$node" eq ".")
		{
			$node = $self->GetCurrentNode();
		}

		$xml .= "<nodeName>$node</nodeName>";
	} # if ($node)

	$xml .= "</controlResource></clusterManage></ncsRequest>";

	log_request($xml);

	$host = $self->GetHost();
	$fh = $self->OpenVfsFile($host, "/Novell/Cluster/ClusterManage.cmd");
	$self->WriteVfsFile($fh, $xml);
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	log_response($xml);

	%results = $self->ParseNcsResults($xml);

	# TODO: Replace 528 with a meaningful constant
	if (528 == $results{"code"})
	{
		console_print("\nResource $resource cannot be onlined because it is secondary\n", 0),
	}
	elsif (509 == $results{"code"})
	{
		console_print("\nNode $node does not exist\n", 0);
	}
	elsif (512 == $results{"code"})
	{
		console_print("\nResource $resource does not exist\n", 0);
	}
	else
	{
        # Output the state of the resource
        $self->ShowResourceList($host, 0, $resource);		# 0 = Don't show header
	} # if (528 == $results{"code"})

	return(1);

} # Execute


#**********************************************************************
# Name:			ParseNcsResults
# Description:	Parses the results from an NCS command
# Parameters:	Buffer to parse
# Return:		Hash with results
#					code -> Error code
#					description -> Description string
# Notes:
#**********************************************************************

# TODO: This should be moved to the base class

sub ParseNcsResults($)
{
	my ($self, $xml) = @_;
	my %results;

	# TODO: Replace 506 with a meaningful constant
	$results{"code"} = 506;									# NCS_UNKNOWN
	$results{"description"} = "Error parsing results";

	if ($xml =~/<ncsReply>(.*?)<\/ncsReply>/s)
	{
		$xml = $1;
		if ($xml =~/<result[\s]+value=\"([\d]+)\">(.*?)<\/result>/s)
		{
			$results{"code"} = $1;

			$xml = $2;
			if ($xml =~/<description>(.*?)<\/description>/s)
			{
				$results{"description"} = $1;
			} # if ($xml =~/<description>(.*?)<\/description>/s)
		} # if ($xml =~/<result[\s]+value=\"([\d]+)\">(.*?)<\/result>/s)
	} # if ($xml =~/<ncsReply>(.*?)<\/ncsReply>/s)

	return(%results);

} # ParseNcsResults

#**********************************************************************
# Name:			Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("CLUSTER ONLINE {resource} {node name}\n");
	console_print("  Starts the specified resource on the most preferred node that is currently\n");
	console_print("  active.  You can start the resource on a different node by specifying that\n");
	console_print("  node in the command.\n");
	console_print("Example: cluster online res1\n");

	return(1);

} # Help

1;

