#****************************************************************************
#
# Copyright (c) 2004 - 2005 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Pools.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Pools;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("pools");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	my ($self) = @_;
	my $fh;
	my $host;
	my $xml;
	my @poollist;
	my $name;
	my $state;
	my $location;
	my $idx = 1;
	my $prefix;

	$host = $self->GetHost();
	$fh = $self->OpenVfsFile($host, "/Novell/Cluster/PoolState.xml");
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	log_response($xml);

	# The grouping must be a minimal match because sometimes sysread returns
	# the XML twice.  Don't ask me why...
	$xml =~ /<ncsReply>[\s]*<pools>(.*?)<\/pools>[\s]*<\/ncsReply>/s;
	$xml = $1;

	if (defined($xml))
	{
		@poollist = sort $xml =~ /<pool>(.*?)<\/pool>/gs;

		my $format = "@<<< @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n";

		# Clear the format output accumulator
		$^A = "";

		foreach $xml (@poollist)
		{
			if ($xml =~ /<name>(.*?)<\/name>/s)
			{
				$name = "Pool $1";
			}
			else
			{
				$name = "";
			}
	
			if ($xml =~ /<state>(.*?)<\/state>/s)
			{
				$state = $1;
			}
			else
			{
				$state = "";
			}
	
			$prefix = "$idx:";
	
			if ($state eq "active")
			{
				if ($xml =~ /<location>(.*?)<\/location>/s)
				{
					$location = $1;
				}
				else
				{
					$location = "";
				}
				
				$location = "on node $location";
			}
			else
			{
				$location = "Not Active";
			}
	
			formline($format, ($prefix, $name, $location));
	
			$idx++;
		} # foreach $xml (@poollist)

		console_print($^A);
		$^A = "";
	}
	else
	{
		console_print("This node is not a member of a cluster\n");
	} # if (defined($xml))

	return(1);

} # Execute

#**********************************************************************
# Name:			Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("CLUSTER POOLS\n");
	console_print("  Lists the NSS pools on the shared disk system that are accessible by\n");
	console_print("  Novell Cluster Services.\n");
	console_print("Example: cluster pools\n");

	return(1);

} # Help

1;

