#****************************************************************************
#
# Copyright (c) 2019 Micro Focus International, PLC. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:      Micro Focus.
#  Workfile:    ClusterCliSnapin_PreferredNodes.pm
#  Contents:    Command line implementation for Novell Cluster Services
#                               and Novell Business Continuity Cluster.
#
#****************************************************************************
package ClusterCliSnapin_PreferredNodes;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;
use XML::LibXML;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:		Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:	Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("preferred_nodes");
} # Param

sub Execute(@)
{
	if(($#ARGV) < 0 )
	{
		console_print("Error: Too few arguments.\n");
		console_print("Usage: cluster preferred_nodes {resource_name}\n");
		return 1;
	}
	my $self = shift;
	my @typeOfRequest = ("preferredNodeInfo");
	my $doc = $self->GetInfoFromCMD("ClusterConfig.cmd","getResourceInfo",\@typeOfRequest,"$ARGV[0]");
	print "Resource $ARGV[0] preferred nodes: \n";
	foreach my $pnode ($doc->findnodes('//preferredNodes'))
	{
		foreach my $mnode ($pnode->findnodes('./node'))
		{
			print $mnode->to_literal();
			print "\n";
		}
	}
}

sub Help(@)
{
	console_print("CLUSTER PREFERRED_NODES {resource}\n");
	console_print("  Displays the preferred nodes for the specified resource\n");
	console_print("Example: cluster preferred_nodes RES_NAME\n");
	return(1);
} # Help
