#****************************************************************************
#
# Copyright (c) 2003 - 2007 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Migrate.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Rename;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("rename");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	if( 3 > scalar( @_ ))
	{
		Help();
		return 0;
	}

	if ( ! defined( open( file_handle, "</admin/Novell/Cluster/NodeState.xml" )))
	{
		console_print( "Failed to retrieve cluster state. Is NCS running?\n" );
		return 0;
	}

        sysread( file_handle, my $content, 2048 );
        close( file_handle );

	my      $my_name="";
	my      $master="";
	if ( $content =~ m/<thisNode>(.*)<\/thisNode>/iog )
	{
		$my_name = $1;
	}

	if( $content =~ m/<masterNode>(.*)<\/masterNode>/iog )
	{
		$master = $1;
	}

	if( "" eq $my_name || "" eq $master )
	{
		console_print( "Failed to retrieve node names. Is NCS running?\n" );
		return 0;
	}

	if( $my_name ne $master )
	{
		console_print( "Command 'cluster rename' only works on the master node of a cluster.\n" );
		return 0;
	}

	my $parameters="[clstrlib.NWCLSTR_RenameResource,\\\"" . $_[1] . "\\\",\\\"" . $_[2] . "\\\"]";
	my $result = `/opt/novell/ncs/bin/ncs-configd.py $parameters 2>/dev/null`;

	if( "0" eq $result )
	{
		console_print( "Resource '" . $_[1] . "' has been renamed to '" . $_[2] . "'.\n" );
		return 1;
	}

	if ( "-1" eq $result )
	{
		console_print( "Resource '" . $_[1] . "' is not found.\n" );
	}
	elsif ( "-2" eq $result )
	{
		console_print( "Resource '" . $_[1] . "' is not in offline state.\n" );
	}
	elsif ( "-3" eq $result )
	{
		console_print( "Resource '" . $_[1] . "' is not found in eDirectory/LDAP.\n" );
	}
	elsif ( "-4" eq $result )
	{
		console_print( "Failed to rename resource '" . $_[1] . "' to '" . $_[2] . "' in eDirectory.\n" );
	}
	elsif ( "-5" eq $result )
	{
		console_print( "Failed to modify resource priority list.\n" );
	}
	else
	{
		console_print( "The operation failed with unknown error (code '$result').\n" );
	}

	return 0;
} # Execute

#**********************************************************************
# Name:                 Help
# Description:  Prints help for the command handler
# Parameters:   List of parameters passed in to the help command
# Return:               true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
        console_print("\nCLUSTER RENAME OLD_RES_NAME NEW_RES_NAME\n");
        console_print("  Used to rename a resource.\n");
        console_print("  The command only works on the master node.\n");
        console_print("  The resource must be in offline state to be renamed.\n");
        console_print("  The new name must not exist prior to the renaming.\n");
        console_print("Example: cluster rename shd_pool_res_01 customized_name22\n");

        return(1);

} # Help

1;

