#****************************************************************************
#
# Copyright (c) 2004 - 2006 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:	Novell, Inc.
#  Workfile:	ClusterCliSnapin_ResetResources.pm
#  Contents:	Command line implementation for Novell Cluster Services
#		and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_ResetResources;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:		Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:	Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("resetresources");

} # Param

#**********************************************************************
# Name:		Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:	true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	my $self = shift;
	my %results;
	my $xml;
	my $host;
	my $fh;

	$host = $self->GetHost();

	if ($self->IsMember($host) && $self->IsBCCLoaded($host))
	{
		# Format the output XML that gets written to the VFS file
		$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>" .
			"<bccRequest><bccManage><resetResources/></bccManage></bccRequest>";

		log_request($xml);

		console_print("\nReseting all resources.  Please wait...\n");

		# Write the command
		$fh = $self->OpenVfsFile($host, "/Novell/Cluster/BCC_Manage.cmd");
		$self->WriteVfsFile($fh, $xml);
		$self->ReadVfsFile($fh, $xml);
		$self->CloseVfsFile($fh);

		log_response($xml);

		# Output the results
		$self->ParseBccResults($xml, \%results, "bccManage", "resetResources");
		console_print("\n$results{\"BccReplyString\"} ($results{\"BccReplyCode\"})\n");
	}
	elsif (!is_remote() && ((-f "sys:\\system\\bccutil.nlm") || (-f "/opt/novell/bcc/sbin/bccutil")))
	{
		# Only call the bccutil function to reset resources when not
		# remoting the CLI and the cluster is not up.

		my $output;
		my $command;

		my $continue;
		my $continue_prompt = 
			"\nIMPORTANT:\n".
			"This node is currently not a member of a cluster.\n".
			"Running this command at this time will only set the\n".
			"secondary state of BCC-enabled resources as stored in\n".
			"the directory.  As such, it is recommended that the\n".
			"cluster be completely down before continuing.\n".
			"Do you wish to proceed? (Y/N) ";

		my $cluster_dn = "";
		my $cluster_dn_prompt;

		if (is_netware())
		{
			# Parse for the prompt
			for (my $idx = 0; $idx < $#ARGV + 1; $idx++)
			{
				if ($ARGV[$idx] eq "--continue")
				{
					$continue = $ARGV[$idx + 1];
					last;
				} # if ($ARGV[$idx] eq "--continue")
			} # for (my $idx = 0; $idx < $#ARGV + 1; $idx++)

			if (!defined($continue))
			{
				# Prompt the user if the operation is OK
				$xml =
					"<query>".
						"<input>".
							"<prompt>".
								$continue_prompt.
							"</prompt>".
							"<flag>--continue</flag>".
						"</input>".
					"</query>";

				console_print($xml);
				return(0);
			} # if (!defined($continue))
		}
		else
		{
			console_print($continue_prompt);

			$continue = console_getstring();
		} # if (is_netware())

		if (uc(substr($continue, 0, 1)) ne "Y")
		{
			# The user cancelled the operation
			console_print("Operation cancelled...\n");
			return(0);
		} # if (uc(substr($prompt, 0, 1)) ne "Y")

		if (!is_netware())
		{
			# Try and determine the DN of the cluster.
			if (-f "/etc/opt/novell/ncs/cluster.xml")
			{
				$output = `cat /etc/opt/novell/ncs/cluster.xml 2>/dev/null | grep dn=`;
			}
			elsif (-f "/var/opt/novell/ncs/cluster.xml")
			{
				$output = `cat /var/opt/novell/ncs/cluster.xml 2>/dev/null | grep dn=`;
			} # if (-f "/etc/opt/novell/ncs/cluster.xml")
			
			if ($output =~ /dn="(.*)"/)
			{
				$cluster_dn = $1;
			} # if ($output =~ /dn="(.*)"/)
		} # if (!is_netware())
	
		if ("" eq $cluster_dn)
		{
			$cluster_dn = "cn=cluster,ou=provo,o=novell";
		} # if ("" eq $cluster_dn)

		$cluster_dn_prompt =
			"\nPlease enter the the distinguished name of the cluster in LDAP format...\n".
			"(example $cluster_dn): ";

		if (is_netware())
		{
			undef($cluster_dn);

			# Parse for the prompt
			for (my $idx = 0; $idx < $#ARGV + 1; $idx++)
			{
				if ($ARGV[$idx] eq "--cluster_dn")
				{
					$cluster_dn = $ARGV[$idx + 1];
					last;
				} # if ($ARGV[$idx] eq "--cluster_dn")
			} # for (my $idx = 0; $idx < $#ARGV + 1; $idx++)

			if (!defined($cluster_dn))
			{
				# Prompt the user if the operation is OK
				$xml =
					"<query>".
						"<input>".
							"<prompt>".
								$cluster_dn_prompt.
							"</prompt>".
							"<flag>--cluster_dn</flag>".
						"</input>".
					"</query>";

				console_print($xml);
				return(0);
			} # if (!defined($prompt))
		}
		else
		{
			console_print($cluster_dn_prompt);

			$cluster_dn = console_getstring();
		}

		if (is_netware())
		{
			$command = "sys:\\system\\bccutil.nlm resetresources -c $cluster_dn";
			system($command); # Doesn't return any indication of failure
		}
		else
		{
			$command = "/opt/novell/bcc/sbin/bccutil resetresources -c $cluster_dn 2>&1";
			$output = `$command`;

			if (0 ne $?)
			{
				console_print("\nCommand output:\n$output\n");
				throw("");
			}
		}

		console_print("\nSuccess(0)\n");
	}
	else
	{
		$self->Help();
		return(0);
	}

	return(1);

} # Execute

#**********************************************************************
# Name:		Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:	true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("\nCLUSTER RESETRESOURCES\n");
	console_print("  BCC: Resets all resources on this cluster to offline and secondary.\n");
	console_print("  This is a recovery proceedure that should be ran when a cluster in\n");
	console_print("  a Business Continuity Cluster is brought back into service.\n\n");
	console_print("  NSMI unload scripts will not be executed if this command is executed\n");
	console_print("  when this node is not a member of a cluster. Therefore, it is required\n");
	console_print("  to manually ensure proper state of attached storage during recovery.\n");
	console_print("Example: cluster resetresources\n");

	return(1);

} # Help

1;

