#****************************************************************************
#
# Copyright (c) 2019 Micro Focus International, PLC. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:	Micro Focus.
#  Workfile:	ClusterCliSnapin_Resource.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)

package ClusterCliSnapin_Resource;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;
use XML::LibXML;
require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:		Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:	Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("resource");
} # Param

sub Execute(@)
{
	if(($#ARGV) < 0 )
	{
		console_print("Error: Too few arguments.\n");
		console_print("Usage: cluster resource {resource_name}\n");
		return 1;
	}
	my $self = shift;
	my $nam = "$ARGV[0]";
	my $resip = "";
	my $cifs = "";
	my $virser = "";
	my $host = $self->GetHost();
	my @typeOfRequest = ("protocolInfo","preferredNodeInfo");
	my $doc2 = $self->GetInfoFromCMD("ClusterConfig.cmd","getResourceInfo",\@typeOfRequest,"$nam");
	foreach my $pnode ($doc2->findnodes('//protocolInfo'))
	{
		$resip = $pnode->findnodes('./ipAddress');
		$virser = $pnode->findnodes('./virtualServerName')->to_literal();
		$cifs = $pnode->findnodes('./cifsServerName')->to_literal();
	}
	my @pref_nodes = ();
	foreach my $pnode ($doc2->findnodes('//preferredNodes'))
	{
		foreach my $mnode ($pnode->findnodes('./node'))
		{
			push @pref_nodes , $mnode->to_literal();
		}
	}
	my @una_nodes = ();
	foreach my $pnode ($doc2->findnodes('//unassignedNodes'))
	{
		foreach my $mnode ($pnode->findnodes('./node'))
		{
			push @una_nodes , $mnode->to_literal();
		}
	}
	print "Resource name: $nam\n" if (length($resip)>0);
	print "Resource IP address: $resip\n" if (length($resip)>0);
	print "Virtual Server: $virser\n" if (length($virser)>0);
	print "Cifs Server: $cifs\n" if (length($cifs)>0);
	print "Preferred Node List:\n@pref_nodes\t\t\n\n" if (length($resip)>0);
	print "Unassigned Node List:\n@una_nodes" if (length($resip)>0);
	print "\n";
}

sub Help(@)
{
	console_print("CLUSTER RESOURCE {resource}\n");
	console_print("  Displays the IP address, virtual server name, CIFS server name, preferred nodes, and unassigned nodes of the specified resource.\n");
	console_print("Example: cluster resource RES_NAME\n");
	return(1);
} # Help
