#****************************************************************************
#
# Copyright (c) 2019 Micro Focus International, PLC. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:      Micro Focus.
#  Workfile:    ClusterCliSnapin_ResourcePolicy.pm
#  Contents:    Command line implementation for Novell Cluster Services
#                               and Novell Business Continuity Cluster.
#
#****************************************************************************

package ClusterCliSnapin_ResourcePolicy;
#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;
use XML::LibXML;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:		Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:	Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("resource-policy");
} # Param

sub Execute(@)
{
	if(($#ARGV+1) < 1 )
	{
		console_print("Error: Too few arguments.\n");
		console_print("Usage: cluster resource-policy {resource_name}\n");
		return 1;
	}
	my $self = shift;
	my @typeOfRequest = ("policyInfo");
	my $doc = $self->GetInfoFromCMD("ClusterConfig.cmd","getResourceInfo",\@typeOfRequest,"$ARGV[0]");
	foreach my $pnode ($doc->findnodes('//policyInfo'))
	{
		foreach my $mnode ($pnode->findnodes('./startMode'))
		{
			foreach my $knode ($mnode->findnodes('./*'))
			{
				print $mnode->nodeName(),": ",$knode->nodeName();
			}
		}
	print "\n";
	foreach my $fail ($pnode->findnodes('./failoverMode'))
	{
		foreach my $knode ($fail->findnodes('./*'))
		{
			print $fail->nodeName(),": ",$knode->nodeName();
		}
	}
	print "\n";
	foreach my $mnode ($pnode->findnodes('./failbackMode'))
	{
		foreach my $knode ($mnode->findnodes('./*'))
		{
			print $mnode->nodeName(),": ",$knode->nodeName();
		}
	}
	print "\n";
	}
}

sub Help(@)
{
	console_print("CLUSTER resource-policy {resource}\n");
	console_print("  Displays the set value for the start mode, failover mode, and failback mode on the specified resource\n");
	console_print("Example: cluster resource-policy RES_NAME\n");
	return(1);
}
