#****************************************************************************
#
# Copyright (c) 2003 - 2005 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Resources.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Resources;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;
use XML::LibXML;
use Getopt::Std;
use Term::ANSIColor;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("resources");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	my $self = shift;
	my $host;

	$host = $self->GetHost();
	console_print("\n");
	if("$#ARGV">-1)
	{
		my %options=();
		getopts("ivcpua", \%options) or exit;
		my @typeOfRequest2 = ("basicInfo", "priorityInfo");
		print color('bold blue');
		print "Name:\t\t\t";
		print "ipAddress\t" if defined ($options{i} || $options{a});
		print "VirtualServer\t\t\t\t" if defined ($options{v} || $options{a});
		print "CifsServer\t\t" if defined ($options{c} || $options{a});
		print "Preferred Nodes\t\t" if defined ($options{p} || $options{a});
		print "Unassigned Nodes" if defined ($options{u} || $options{a});
		print "\n";
		print color('reset');
		my $doc = $self->GetInfoFromCMD("ClusterConfig.cmd","getClusterInfo",\@typeOfRequest2,"");
		my @res_list = ();
		foreach my $jnode ($doc->findnodes('//resourceList'))
		{
			foreach my $knode ($jnode->findnodes('./name'))
			{
				push @res_list , $knode->to_literal();
			}
		}
		foreach my $pnode (@res_list)
		{
			#foreach my $knode ($pnode->findnodes('./name'))
			{
				my $nam = $pnode ;
				my $sp_count = 24;
				my $resip = "";
				my $cifs = "";
				my $virser = "";
				my @typeOfRequest = ("protocolInfo","preferredNodeInfo");
				my $doc2 = $self->GetInfoFromCMD("ClusterConfig.cmd","getResourceInfo",\@typeOfRequest,"$nam");
				if($options{i} || $options{v} || $options{c} || $options{a})
				{
					foreach my $pnode ($doc2->findnodes('//protocolInfo'))
					{
						if ($options{i} || $options{a})
						{
							$resip = $pnode->findnodes('./ipAddress')->to_literal();
						}
						if ($options{v} || $options{a})
						{
							$virser = $pnode->findnodes('./virtualServerName')->to_literal();
							if (length($virser) > 0)
							{
								my @virser_fdn = split(',', $virser);
								$virser = $virser_fdn[0];
							}
						}
						if ($options{c} || $options{a})
						{
							$cifs = $pnode->findnodes('./cifsServerName')->to_literal();
						}
					}
					# separated this out because the protocol info is valid only for volume resources
					if ($options{i} || $options{a})
					{
						$sp_count = $sp_count + 16;
					}
					if ($options{v} || $options{a})
					{
						$sp_count = $sp_count + 40;
					}
					if ($options{c} || $options{a})
					{
						$sp_count = $sp_count + 24;
					}
				}
				my @pref_nodes = ();
				if($options{p} || $options{a})
				{
					foreach my $pnode ($doc2->findnodes('//preferredNodes'))
					{
						foreach my $mnode ($pnode->findnodes('./node'))
							{
								push @pref_nodes , $mnode->to_literal();
							}
					}
				}
				my @una_nodes = ();
				if($options{u} || $options{a})
				{
					foreach my $pnode ($doc2->findnodes('//unassignedNodes'))
					{
						foreach my $mnode ($pnode->findnodes('./node'))
						{
							push @una_nodes , $mnode->to_literal();
						}
					}
				}
				printf "%-24s" , "$nam" if defined ($options{c} || $options{a} || $options{i} || $options{p} || $options{v} || $options{u});
				print "$resip" . " " x (16-length($resip)) if defined ($options{i} || $options{a});
				print "$virser" . " " x (40-length($virser)) if defined ($options{v} || $options{a});
				print "$cifs" . " " x (24-length($cifs)) if defined ($options{c} || $options{a});
				my $len_pref = scalar(@pref_nodes);
				my $len_una = scalar(@una_nodes);
				my $len_total = $len_pref + $len_una;
				my $i = 0;
				my $j = 0;
				while($len_total > 0)
				{
					if($options{p} || $options{a})
					{
						if($len_pref > 0)
						{
							if($i != 0)
							{
								print " " x $sp_count . $pref_nodes[$i];
							}
							else
							{
							print  $pref_nodes[$i];
							}
							$i = $i + 1;
							$len_total = $len_total - 1;
							$len_pref = $len_pref - 1;
						}
						if($len_pref == 0 )
							{
							$i = $i - 1;
							}
					}
					if($options{u} || $options{a})
					{
						if($len_una > 0)
						{
							if($j > $i)
							{
								if($options{p} || $options{a})
								{
									print " " x $sp_count . "\t\t\t" . $una_nodes[$j];
								}
								else
								{
									print " " x $sp_count . $una_nodes[$j];
								}
							}
							else
							{
								if($options{p} || $options{a})
								{
									print "\t\t\t" . $una_nodes[$j];
								}
								else
								{
									print $una_nodes[$j];
								}
							}
							$j = $j + 1;
							$len_total = $len_total - 1;
							$len_una = $len_una - 1;
						}
					}
						print "\n";
				}
				print "\n";
			}
		}
	}
	else
	{
		return($self->ShowResourceList($host, 1, 0));		# 1 = show header, 0 = Don't show specific resource (list all)
	}
} # Execute

#**********************************************************************
# Name:			Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("\nCLUSTER RESOURCES\n");
	console_print("  Lists all resources that currently exist in the cluster.  The\n");
	console_print("  resources do not have to be online or running.  Includes the\n");
	console_print("  number of lives, running or offline, and which node the resources\n");
	console_print("  are running on.  If this cluster is a member of a BCC, then the\n");
	console_print("  state of the resource (primary or secondary) is displayed as\n");
	console_print("  well.  Secondary resources in a BCC cluster also show the name\n");
	console_print("  of the peer cluster where the resource is primary.  This command\n");
	console_print("  works from any active node.\n");
	console_print("Example: cluster resources {-i | -v | -p | -u | -c | -a}\n");
	
	return(1);

} # Help

1;

