#****************************************************************************
#
# Copyright (c) 2004 - 2005 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Restart.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Restart;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("restart");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	my ($self, $seconds, $third ) = @_;
	my $fh;
	my $host;
	my $xml;

	if( ! defined( $third ) || '-y' ne $third )
        {
		my $ack;

		console_print( "\nWARNING!\n\n" );
		console_print( "  This command will force all the nodes currently\n" );
		console_print( "  in the cluster to leave temporarily and may result\n" );
		console_print( "  in interruptions to the applications and services\n" );
		console_print( "  managed by Novell Cluster Services.\n\n" );
		console_print( "Are you sure you want to restart the cluster (yes/no)? " );
		$ack = console_getstring();
		if( 'yes' ne $ack )
		{
			console_print("\nOperation cancelled.\n");
			return( 1 );
		}
	}

	$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>";

	if (defined($seconds) && 0 ne $seconds)
	{
		$xml .= "<ncsRequest><restart delay=\"$seconds\"/></ncsRequest>";
	}
	else
	{
		$xml .= "<ncsRequest><restart/></ncsRequest>";
	} # if (defined($seconds) && 0 ne $seconds)

	log_request($xml);

	# Output the standard NCS information
	$host = $self->GetHost();
	$fh = $self->OpenVfsFile($host, "/Novell/Cluster/Cluster.cmd");
	$self->WriteVfsFile($fh, $xml);
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	log_response($xml);

	# The grouping must be a minimal match because sometimes sysread returns
	# the XML twice.  Don't ask me why...
	$xml =~ /<ncsReply>[\s]*<failed>(.*?)<\/failed>[\s]*<\/ncsReply>/s;
	$xml = $1;

	if ($xml)
	{
		console_print("There was an error while restarting the cluster\n");
		console_print("Error: \"$xml\"\n");
	} # if ($xml)
	
	return(1);

} # Execute

#**********************************************************************
# Name:			Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("\nCLUSTER RESTART {SECONDS}\n");
	console_print("  Restarts Cluster Services software on all servers in the cluster.\n");
	console_print("Example: cluster restart 60\n\n");

	return(1);

} # Help

1;

