#****************************************************************************
#
# Copyright (c) 2019 Micro Focus International, PLC. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:      Micro Focus.
#  Workfile:    ClusterCliSnapin_Script.pm
#  Contents:    Command line implementation for Novell Cluster Services
#                               and Novell Business Continuity Cluster.
#
#****************************************************************************


package ClusterCliSnapin_Script;
#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;
use XML::LibXML;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:		Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:	Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("script");
} # Param

sub Execute(@)
{
	if(($#ARGV) < 1)
	{
		console_print("Error: Too few arguments\n");
		console_print("Usage: cluster script {load-script | unload-script | monitor-script | all}  {resource-name}\n");
		return 1;
	}
	my $self = shift;
	my @typeOfRequest = ("scriptInfo");
	my $doc = $self->GetInfoFromCMD("ClusterConfig.cmd","getResourceInfo",\@typeOfRequest,"$ARGV[1]");
	if("$ARGV[0]" eq "load-script")
	{
		print("Load Script for resource $ARGV[1]:\n");
		foreach my $pnode ($doc->findnodes('//loadScript'))
		{
			print $pnode->findvalue('./script');
			print "\n";
		}
	}
	elsif("$ARGV[0]" eq "unload-script")
	{
		print("Unload Script for resource $ARGV[1]:\n");
		foreach my $pnode ($doc->findnodes('//unloadScript'))
		{
			print $pnode->findvalue('./script');
			print "\n";
		}
	}
	elsif("$ARGV[0]" eq "monitor-script")
	{
		print("Monitor Script for resource $ARGV[1]:\n");
		foreach my $pnode ($doc->findnodes('//monitorScript'))
		{
			print $pnode->findvalue('./script');
			print "\n";
		}
	}
	elsif("$ARGV[0]" eq "all")
	{
		print("Load Script for resource $ARGV[1]:\n");
		foreach my $pnode ($doc->findnodes('//loadScript'))
		{
			print $pnode->findvalue('./script');
			print "\n";
		}
		print("\nUnload Script for resource $ARGV[1]:\n");
		foreach my $pnode ($doc->findnodes('//unloadScript'))
		{
			print $pnode->findvalue('./script');
			print "\n";
		}
		print("\nMonitor Script for resource $ARGV[1]:\n");
		foreach my $pnode ($doc->findnodes('//monitorScript'))
		{
			print $pnode->findvalue('./script');
			print "\n";
		}

	}
	else
	{
		$self->Help();
	}
}

sub Help(@)
{
	console_print("CLUSTER script {load-script | unload-script | monitor-script | all} {resource}\n");
	console_print("  Displays the script ditails for the specified resource\n");
	console_print("Example: cluster script load-script RES_NAME\n");
	return(1);
}
