#****************************************************************************
#
# Copyright (c) 2004 - 2005 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Set.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Set;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("set");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	my $self = shift(@_);			# Use shift to pull the params off the arg array
	my $param;# = lc(shift(@_));
	my $value;# = lc(shift(@_));
	my $fh;
	my $host;
	my $xml;
	my $vfsfile	= "/Novell/Cluster/ClusterConfig.cmd";
	my $result = -1;
	my $description = "Unable to get error description";

    if (!defined $_[0] || "" eq $_[0])
	{
		console_print("\nInvalid syntax for param\n");
		$self->Help();
		return(1);
	}
	$param = lc(shift(@_));

    if (!defined $_[0] || "" eq $_[0])
	{
		console_print("\nYou must specify a value for parameter \"$param\"\n");
		return(1);
	}
	$value = lc(shift(@_));

	if ($param eq "ipaddress")
	{
		$param = "<basicInfo><ipAddress>$value<\/ipAddress><\/basicInfo>";
	}
	elsif ($param eq "port")
	{
		$param = "<basicInfo><port>$value<\/port><\/basicInfo>";
	}
	elsif ($param eq "quorumwait")
	{
		$param = "<basicInfo><quorum><timeout>$value<\/timeout><\/quorum><\/basicInfo>";
	}
	elsif ($param eq "quorum")
	{
		$param = "<basicInfo><quorum><membership>$value<\/membership><\/quorum><\/basicInfo>";
	}
	elsif ($param eq "heartbeat")
	{
		$param = "<protocolInfo><heartbeat>$value<\/heartbeat><\/protocolInfo>";
	}
	elsif ($param eq "tolerance")
	{
		$param = "<protocolInfo><tolerance>$value<\/tolerance><\/protocolInfo>";
	}
	elsif ($param eq "masterwatchdog")
	{
		$param = "<protocolInfo><masterWatchdog>$value<\/masterWatchdog><\/protocolInfo>";
	}
	elsif ($param eq "slavewatchdog")
	{
		$param = "<protocolInfo><slaveWatchdog>$value<\/slaveWatchdog><\/protocolInfo>";
	}
	elsif ($param eq "maxretransmits")
	{
		$param = "<protocolInfo><maxRetransmits>$value<\/maxRetransmits><\/protocolInfo>";
	}
	elsif ($param eq "enableemail")
	{
		if ($value eq "off")
		{
			$param = "<notificationInfo state=\"disabled\"\/>";
		}
		elsif ($value eq "critical")
		{
			$param = "<notificationInfo state=\"enabled\"><notificationType><onlyCritical\/><\/notificationType><\/notificationInfo>";
		}
		elsif ($value eq "verbose")
		{
			$param = "<notificationInfo state=\"enabled\"><notificationType><verbose\/><\/notificationType><\/notificationInfo>";
		}
		else
		{
			console_print("\nInvalid value \"$value\" used for paramemter \"enableemail\"\n");
			console_print("Valid values are \"off\", \"critical\" and \"verbose\" \n");

			return(1);
		}
	}
	elsif ($param eq "emailaddresses")
	{
		my $email;

		$param = "<notificationInfo><emailAddresses>";

		push(@_, $value);		# push the first email address back on the arg list
		
		foreach $email (@_)
		{
			$param .= "<email>$email<\/email>";
		} # foreach $email (@_)

		$param .= "<\/emailAddresses><\/notificationInfo>";
	}
	elsif ($param eq "emailoptions")
	{
		if ($value eq "xml")
		{
			$param = "<notificationInfo><xmlMsg state=\"enabled\"\/><\/notificationInfo>";
		}
		elsif ($value eq "text")
		{
			$param = "<notificationInfo><xmlMsg state=\"disabled\"\/><\/notificationInfo>";
			
		}
		else
		{
			console_print("\nInvalid value \"$value\" used for paramemter \"emailoptions\"\n");
			return(1);
		} #if ($value eq "xml")
	}
	elsif ($param eq "resourcepriority")
	{
		my $resource;

		$param = "<priorityInfo><resourceList>";
		$param .= "<name>$value<\/name>";
		
		foreach $resource (@_)
		{
			$param .= "<name>$resource<\/name>";
		}

		$param .= "<\/resourceList><\/priorityInfo>";
	}
	else
	{
		console_print("\nInvalid paramemter \"$param\"\n");
		$self->Help();
		return(1);
	} # if ($param eq "ipaddress")

	$xml	= "<virtualIO><datastream name=\"command\"/></virtualIO>";
	$xml	.= "<ncsRequest><clusterConfig><setClusterInfo>";
	$xml	.= $param;
	$xml	.= "</setClusterInfo></clusterConfig></ncsRequest>";

	log_request($xml);

	# Send the command and read the result
	$host = $self->GetHost();
	$fh = $self->OpenVfsFile($host, $vfsfile);
	$self->WriteVfsFile($fh, $xml);
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	log_response($xml);

	# The grouping must be a minimal match because sometimes sysread returns
	# the XML twice.  Don't ask me why...
	$xml =~ /<ncsReply>[\s]*<clusterConfig>[\s]*<setClusterInfo>(.*?)<\/setClusterInfo>[\s]*<\/clusterConfig>[\s]*<\/ncsReply>/s;
	$xml = $1;

	# Parse for and return the results
	if ($xml =~ /<result value="(.*?)">/s)
	{
      $result = $1;
	}
	if ($xml =~ /<description>(.*?)<\/description>/s)
	{
		$description = $1;
	}

	if (0 == $result)
	{
		console_print("\nSuccess\n");
	}
	else
	{
		console_print("\nError [$result]\n$description\n");
	}

	return(1);

} # Execute

#**********************************************************************
# Name:			Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("\nCLUSTER SET <PARAMETER> <VALUE>\n");
	console_print("  Used to set individual configuration parameters for the cluster.\n");
	console_print("  <PARAMETER> can be one of the following cluster configuration parameters:\n");
	console_print("  IPADDRESS - sets the IP address of the cluster master.\n");
	console_print("  PORT - sets the IP port of the cluster master.\n");
	console_print("  QUORUMWAIT - Sets the quorum wait time\n");
	console_print("  QUORUM - Sets the quorum membership value\n");
	console_print("  HEARTBEAT - Sets the cluster heartbeat value\n");
	console_print("  TOLERANCE - Sets the cluster tolerance value\n");
	console_print("  MASTERWATCHDOG - Sets the master watch dog value\n");
	console_print("  SLAVEWATCHDOG - Sets the slave watch dog value\n");
	console_print("  MAXRETRANSMITS - Sets the maximum number of retransmissions allowed\n");
	console_print("  ENABLEEMAIL - Enables/disables e-mail notification\n");
	console_print("  EMAILADDRESSES - Sets the e-mail addresses used for email notification\n");
	console_print("  EMAILOPTIONS - Sets the e-mail notification options\n");
	console_print("  RESOURCEPRIORITY - Sets the resource priority for the cluster\n");
	console_print("Example: cluster set ipaddress 10.1.1.1\n");

	# TODO: More help is needed

	return(1);

} # Help

1;

