#****************************************************************************
#
# Copyright (c) 2004 - 2006 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Stats.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Stats;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("stats");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	my ($self, $verb) = @_;
	my $fh;
	my $host;
	my $xml;
	my $err;
	my $vfsfile	= "/Novell/Cluster/ClusterManage.cmd";

	if (defined($verb))
	{
		$verb = lc($verb);
		if ($verb ne "display" && $verb ne "clear")
		{
			$self->Help();
			return(1);
		} # if ($verb ne "display" && $verb ne "clear")
	}
	else
	{
		$self->Help();
		return(1);
	} # if (defined($verb))

	$xml = "<virtualIO><datastream name=\"command\"/></virtualIO>";
	$xml .= "<ncsRequest><clusterManage><controlCluster><action>";
   
	if ($verb eq "clear")
	{
		$xml .= "<stats clear=\"yes\"/>";
	}
	else
	{
		$xml .= "<stats/>";
	}

	$xml .= "</action></controlCluster></clusterManage></ncsRequest>";

	log_request($xml);

	# Output the standard NCS information
	$host = $self->GetHost();
	$fh = $self->OpenVfsFile($host, $vfsfile);
	$self->WriteVfsFile($fh, $xml);
	$self->ReadVfsFile($fh, $xml);
	$self->CloseVfsFile($fh);

	log_response($xml);

	# The grouping must be a minimal match
	$xml =~ /<stats>(.*?)<\/stats>/s;
	$xml = $1;

	if (defined($xml))
	{
		# Success
		if ($verb eq "clear")
		{
			console_print("\nCluster stats have been reset.\n");
		}
		else
		{
			my $time1;
			my $time2;
			my $nodeName;
			my $nodeNumber;
			my $value1;
			my $value2;
			my @nodeList;
			my @list;
			my $temp;
			my $first;

			# Print the header
			$xml =~ /<startTime>(.*?)<\/startTime>/s;
			if (defined($1))
			{
				$time1 = $self->GetTime($1);
			}
			else
			{
				$time1 = "unknown";
			}

			$xml =~ /<endTime>(.*?)<\/endTime>/s;
			if (defined($1))
			{
				$time2 = $self->GetTime($1);
			}
			else
			{
				$time2 = "unknown";
			}

			$xml =~ /<name>(.*?)<\/name>/s;
			if (defined($1))
			{
				$nodeName = $1;
			}
			else
			{
				$nodeName = "unknown";
			}

			$xml =~ /<nodeNumber>(.*?)<\/nodeNumber>/s;
			if (defined($1))
			{
				$nodeNumber = $1;
			}
			else
			{
				$nodeNumber = "unknown";
			}

			$xml =~ /<heartbeat>(.*?)<\/heartbeat>/s;
			if (defined($1))
			{
				$value1 = $1;
			}
			else
			{
				$value1 = "unknown";
			}

			$xml =~ /<tolerance>(.*?)<\/tolerance>/s;
			if (defined($1))
			{
				$value2 = $1;
			}
			else
			{
				$value2 = "unknown";
			}

			console_print("\nReport taken: startTime= $time1, endTime= $time2\n");
			console_print("\tnode=$nodeNumber, name=$nodeName, heartbeat=$value1, tolerance=$value2\n");

			# Print the heartbeat counters
			$xml =~ /<heartbeatCount>(.*?)<\/heartbeatCount>/gs;
			if (defined($1))
			{
				console_print("\t");
				$temp = $1;

				for (my $nIdx = 0; $nIdx < 256; ++$nIdx)
				{
					if ($temp =~ /<$nIdx>(.*?)<\/$nIdx>/gs)
					{
						if (0 != $nIdx)
						{
							console_print(", ");							
						}
						
						console_print("$nIdx");
						console_print("x=$1");						
					}	
				}
			}

			# Print the node specific stats
			@nodeList = $xml =~ /<nodeInfo>(.*?)<\/nodeInfo>/gs;

			foreach $temp (@nodeList)
			{
				# Print the node max/min ticks and dates
				$temp =~ /<name>(.*?)<\/name>/s;
				if (defined($1))
				{
					$nodeName = $1;
				}
				else
				{
					$nodeName = "unknown";
				}

				$temp =~ /<nodeNumber>(.*?)<\/nodeNumber>/s;
				if (defined($1))
				{
					$nodeNumber = $1;
				}
				else
				{
					$nodeNumber = "unknown";
				}

				$temp =~ /<maxTicks>(.*?)<\/maxTicks>/s;
				if (defined($1))
				{
					$value1 = $self->GetSeconds($1);
				}
				else
				{
					$value1 = "unknown";
				}

				$temp =~ /<minTicks>(.*?)<\/minTicks>/s;
				if (defined($1))
				{
					$value2 = $self->GetSeconds($1);
				}
				else
				{
					$value2 = "unknown";
				}

				$temp =~ /<maxTickTime>(.*?)<\/maxTickTime>/s;
				if (defined($1))
				{
					$time1 = $self->GetTime($1);
				}
				else
				{
					$time1 = "unknown";
				}

				$temp =~ /<lastTickTime>(.*?)<\/lastTickTime>/s;
				if (defined($1))
				{
					$time2 = $self->GetTime($1);
				}
				else
				{
					$time2 = "unknown";
				}

				console_print("\n\nnode $nodeNumber, name $nodeName, ");
				console_print("maxTicks=$value1 sec at $time1, ");
				console_print("minTicks=$value2 sec, ");
				console_print("lastTickDate $time2\n");

				# Print the node sample
				$temp =~ /<sample>(.*?)<\/sample>/s;
				if (defined($1))
				{
					@list = $1 =~/<data>(.*?)<\/data>/gs;

					$first = 1;
					foreach my $temp (@list)
					{						
						if (!$first)
						{
							console_print(", ");
						}
						
						$value1 = $self->GetSeconds($temp);
						console_print("$value1");
						$first = 0;
					}
				}
			}

			# Print the SBD stats
			if ($xml =~ /<sbd>(.*?)<\/sbd>/s)
			{
				$temp = $1;
					
				# Print the SBD max/min ticks and dates
				$temp =~ /<maxTicks>(.*?)<\/maxTicks>/s;
				if (defined($1))
				{
					$value1 = $self->GetSeconds($1);
				}
				else
				{
					$value1 = "unknown";
				}

				$temp =~ /<minTicks>(.*?)<\/minTicks>/s;
				if (defined($1))
				{
					$value2 = $self->GetSeconds($1);
				}
				else
				{
					$value2 = "unknown";
				}

				$temp =~ /<maxTickTime>(.*?)<\/maxTickTime>/s;
				if (defined($1))
				{
					$time1 = $self->GetTime($1);
				}
				else
				{
					$time1 = "unknown";
				}

				$temp =~ /<lastTickTime>(.*?)<\/lastTickTime>/s;
				if (defined($1))
				{
					$time2 = $self->GetTime($1);
				}
				else
				{
					$time2 = "unknown";
				}

				console_print("\n\nSBD STATS: ");
				console_print("maxTicks=$value1 sec at $time1, ");
				console_print("minTicks=$value2 sec, ");
				console_print("lastTickDate $time2\n");

				# Print the SBD sample
				$temp =~ /<sample>(.*?)<\/sample>/s;
				if (defined($1))
				{
					@list = $1 =~/<data>(.*?)<\/data>/gs;

					$first = 1;
					foreach $temp (@list)
					{
						if (!$first)
						{
							console_print(", ");
						}
						
						$value1 = $self->GetSeconds($temp);
						console_print("$value1");
						$first = 0;
					}
				}
			}

			console_print("\n");
		} # if ($verb eq "clear")
	}
	else
	{
      console_print("\nThere was an error issuing the stats command.\n");
	} # if (defined($xml))
	
	return(1);

} # Execute

#**********************************************************************
# Name:			Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("\nCLUSTER STATS {DISPLAY / CLEAR}\n");
	console_print("  The \"DISPLAY\" parameter reports the node number, name, and\n");
	console_print("  heartbeat information on the console screen.  The \"CLEAR\" parameter\n");
	console_print("  resets the various stats counters.  This command is useful for\n");
	console_print("  troubleshooting network problems related to the cluster heartbeat\n");
	console_print("  protocol.\n");
	console_print("Example: cluster stats display\n");

	return(1);

} # Help

#**********************************************************************
# Name:			GetSeconds
# Description:	Converts micro-seconds to seconds in string format
# Parameters:	micro-seconds
# Return:		Seconds (string)
# Notes:
#**********************************************************************
sub GetSeconds($)
{
	my ($self, $us) = @_;

	return(sprintf("%.3f", $us / 1000000));

} # GetSeconds

#**********************************************************************
# Name:			GetTime
# Description:	Converts seconds since 1/1/1970 to a time string
# Parameters:	Seconds since 1/1/1970
# Return:		Time string
# Notes:
#**********************************************************************
sub GetTime($)
{
	my ($self, $time) = @_;
	my $str;

	if (0 != $time)
	{
#		my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime($time);
#		$str = "$mon-$mday-$year $hour:$min:$sec";
		$str = localtime($time);
	}
	else
	{
		$str = "";
	}

	return($str);

} # GetTime

1;

