#****************************************************************************
#
# Copyright (c) 2003 - 2005 Novell, Inc. All Rights Reserved.
# THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND TREATIES.
# NO PART OF THIS WORK MAY BE USED, PRACTICED, PERFORMED COPIED, DISTRIBUTED,
# REVISED, MODIFIED, TRANSLATED, ABRIDGED, CONDENSED, EXPANDED, COLLECTED,
# COMPILED, LINKED, RECAST, TRANSFORMED OR ADAPTED WITHOUT THE PRIOR WRITTEN
# CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION OF THIS WORK WITHOUT
# AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO CRIMINAL AND CIVIL LIABILITY.
#
#  Author:		Novell, Inc.
#  Workfile:	ClusterCliSnapin_Status.pm
#  Contents:	Command line implementation for Novell Cluster Services
#				and Novell Business Continuity Cluster.
#
#****************************************************************************

# The package name must be the same as the file name (including case)
package ClusterCliSnapin_Status;

#**********************************************************************
#	Use Statements
#**********************************************************************
use strict;
use warnings;
use diagnostics;
use ClusterCliUtils;

require ClusterCliSnapinInterface;
our @ISA = ("ClusterCliSnapinInterface");

#**********************************************************************
#	Functions
#**********************************************************************

#**********************************************************************
# Name:			Param
# Description:	Returns the name of the parameter this class handles
# Parameters:	None.
# Return:		Paramter string
# Notes:
#**********************************************************************
sub Param()
{
	return("status");

} # Param

#**********************************************************************
# Name:			Execute
# Description:	Executes the command handler
# Parameters:	List of parameters for the command.
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Execute(@)
{
	my ($self, $resource) = @_;
	my $host;

	# Get the host, querying the user if necessary
	$host = $self->GetHost();

	if (!$resource)
	{
		if ($self->IsBCCLoaded($host))
		{
			$self->ShowBccPeers($host);
			console_print("\n");
		} # if ($self->IsBCCLoaded($host))
	} # if (!$resource)

	return($self->ShowResourceList($host, 0, $resource));		# 0 = Don't show header

} # Execute

#**********************************************************************
# Name:			Help
# Description:	Prints help for the command handler
# Parameters:	List of parameters passed in to the help command
# Return:		true on success.  false otherwise.
# Notes:
#**********************************************************************
sub Help(@)
{
	console_print("\nCLUSTER STATUS {resource}\n");
	console_print("  Used to report the status of a resource.  Includes the number\n");
	console_print("  of lives, running or offline, and which node the resource is\n");
	console_print("  running on.  If this cluster is a member of a BCC, then the\n");
	console_print("  state of the resource (primary or secondary) is displayed as\n");
	console_print("  well as the names of the peer clusters.  Secondary resources\n");
	console_print("  in a BCC cluster also show the name of the peer cluster where\n");
	console_print("  the resource is primary.  This command works from any active\n");
	console_print("  node.\n");
	console_print("Example: cluster status res1\n");

	return(1);

} # Help

1;

